pub struct AutomatedShippingSettings {
    pub has_automated_shipping_settings: Option<bool>,
    pub automated_carrier: Option<String>,
    pub automated_ship_method: Option<String>,
}
AutomatedShippingSettings : Contains information regarding the Shipping Settings Automation program, such as whether the order’s shipping settings were generated automatically, and what those settings are.

Fields

has_automated_shipping_settings: Option<bool>

When true, this order has automated shipping settings generated by Amazon. This order could be identified as an SSA order.

automated_carrier: Option<String>

Auto-generated carrier for SSA orders.

automated_ship_method: Option<String>

Auto-generated ship method for SSA orders.

Implementations

Contains information regarding the Shipping Settings Automation program, such as whether the order’s shipping settings were generated automatically, and what those settings are.